package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaDesign;

public interface IBisTtsaDesignService {
    BisTtsaDesign selectBisTtsaDesignByGuid(String guid);
    List<BisTtsaDesign> selectBisTtsaDesignList(BisTtsaDesign bisTtsaDesign);
    int insertBisTtsaDesign(BisTtsaDesign bisTtsaDesign);
    int updateBisTtsaDesign(BisTtsaDesign bisTtsaDesign);
    int deleteBisTtsaDesignByGuid(String guid);
    int deleteBisTtsaDesignByGuids(String[] guids);
}
